@@ -10,10 +10,9 @@ test_that("github helper functions work", {
   )
 
   withr::with_dir(paste0(tempdir(), sprintf("/%s", Sys.getenv("CIRCLE_REPO"))), {
-
     # github_info() ------------------------------------------------------------
     if (Sys.getenv("CI") != "") {
-      info <- github_info(.token = Sys.getenv("PAT_GITHUB"))
+      info <- github_info(.token = Sys.getenv("CIRCLE_R_PACKAGE_GITHUB_PAT"))
     } else {
       info <- github_info()
     }
